import { Handle } from "dojo/interfaces";
import { ExtensionEvent } from "dojo/on";

declare namespace a11yclick {

    interface A11yClick {

        /**
         * Custom press, release, and click synthetic events
         * which trigger on a left mouse click, touch, or space/enter keyup.
         */
        (node: HTMLElement, listener: Function): Handle;

        /**
         * Mousedown (left button), touchstart, or keydown (space or enter) corresponding to logical click operation.
         */
        press: ExtensionEvent;

        /**
         * Mouseup (left button), touchend, or keyup (space or enter) corresponding to logical click operation.
         */
        release: ExtensionEvent;

        /**
         * Mouse cursor or a finger is dragged over the given node.
         */
        move: ExtensionEvent;
    }

}

declare const a11yclick: a11yclick.A11yClick;
export = a11yclick;
